Group: System/Libraries
# see https://bugzilla.altlinux.org/show_bug.cgi?id=10382
%define _localstatedir %{_var}
Name:           tse3
Version:        0.3.1
Release:        alt4_34
Summary:        MIDI Sequencer Engine
License:        GPL+
URL:            http://tse3.sourceforge.net/
Source:         http://downloads.sourceforge.net/tse3/%{name}-%{version}.tar.gz
# patch for archs where size_t != unsigned int
# Fixes tse3 on amd64 systems, possibly others.
# Adapted from ALT Linux
#Patch0:         tse3-0.2.7-size_t-64bit.patch
Patch0:         tse3-size_t-64bit.patch
# This one is to fix compilation issues with gcc 4.3
Patch1:         tse3-gcc43.patch
# Fix FTBFS
Patch2:         tse3-autoconf.patch
BuildRequires:  gcc-c++
BuildRequires:  libalsa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
Source44: import.info

%description
TSE3 is a powerful open source sequencer engine written in C++. It is a 
'sequencer engine' because it provides the actual driving force elements of a
sequencer but provides no form of user interface. Sequencer applications or 
multimedia presentation packages will incorporate the TSE3 libraries to 
provide a user with MIDI sequencing facilities.

%package devel
Group: System/Libraries
Summary:        Development packages for the TSE3 MIDI Sequencer Library
Requires:       %{name} == %{version}-%{release}

%description devel
TSE3 is a powerful open source sequencer engine written in C++. It is a 
'sequencer engine' because it provides the actual driving force elements of a
sequencer but provides no form of user interface. Sequencer applications or 
multimedia presentation packages will incorporate the TSE3 libraries to 
provide a user with MIDI sequencing facilities.

This package holds the development documentation, examples and header files 
for TSE3.

%prep
%setup -q
%patch0 -p2 -b .64bit
%patch1 -p2 -b .gcc43
%patch2 -p1 -b .autoconf

# Fix strange permissions issues
find . -name "*.cpp" -perm /111 -exec chmod 644 {} \;
find . -name "*.h" -perm /111 -exec chmod 644 {} \;

# Fix encoding issues
for i in demos/Demo.tse3 doc/History; do
    iconv -o $i.iso88591 -f iso88591 -t utf8 $i
    touch -r $i $i.iso88591
    mv -f $i.iso88591 $i
done


%build
# Need a newer configure script
autoreconf -fi

# OSS is being deprecated
%configure --with-alsa --with-mutex --with-doc-install --without-oss
# Parallel make not supported
make

%install
make install DESTDIR=%{buildroot} INSTALL="install -p" \
     docsdir=%{_docdir}/%{name}-devel-%{version}/HTML

# Sort out the development documentation. We don't want everything cluttered.

# These files belong to the devel documentation contentwise:
install -pm 0644 ChangeLog NEWS README THANKS TODO \
        %{buildroot}%{_docdir}/%{name}-devel-%{version}/

# Create a demos subdir and install all available demos in there:
install -d -m 0755 %{buildroot}%{_docdir}/%{name}-devel-%{version}/demos/
mv %{buildroot}%{_docdir}/%{name}-devel-%{version}/HTML/*.tse* \
    %{buildroot}%{_docdir}/%{name}-devel-%{version}/demos/
install -pm 0644 demos/*.ins demos/*.mid demos/*.tse* \
    %{buildroot}%{_docdir}/%{name}-devel-%{version}/demos/

# Provide the example source files in devel documentation:
make -C src/examples/ clean
cp -a src/examples/ %{buildroot}%{_docdir}/%{name}-devel-%{version}/

# Remove unneeded files:
rm -rf %{buildroot}%{_docdir}/%{name}-devel-%{version}/*/.deps \
       %{buildroot}%{_docdir}/%{name}-devel-%{version}/*/*/.deps

# Remove the library with the non-standard filename (this is a carbon copy
# of lib%{name}.so.x so we are not losing anything) and the .la file.
rm -rf %{buildroot}/%{_libdir}/lib%{name}-%{version}.so \
       %{buildroot}/%{_libdir}/*.la


%files
%doc AUTHORS
%doc --no-dereference COPYING 
%{_bindir}/*
%{_libdir}/libtse3.so.*
%{_mandir}/man1/*


%files devel
%doc %{_docdir}/%{name}-devel-%{version}
%{_includedir}/*
%{_mandir}/man3/*
%{_libdir}/libtse3.so

%changelog
* Sat Mar 23 2024 Igor Vlasenko <viy@altlinux.org> 0.3.1-alt4_34
- update to new release by fcimport

* Thu Aug 31 2023 Igor Vlasenko <viy@altlinux.org> 0.3.1-alt4_33
- update to new release by fcimport

* Wed Feb 22 2023 Igor Vlasenko <viy@altlinux.org> 0.3.1-alt4_32
- update to new release by fcimport

* Sun Aug 07 2022 Igor Vlasenko <viy@altlinux.org> 0.3.1-alt4_31
- update to new release by fcimport

* Sat Feb 05 2022 Igor Vlasenko <viy@altlinux.org> 0.3.1-alt4_30
- update to new release by fcimport

* Mon Aug 02 2021 Igor Vlasenko <viy@altlinux.org> 0.3.1-alt4_29
- update to new release by fcimport

* Wed Mar 17 2021 Igor Vlasenko <viy@altlinux.org> 0.3.1-alt4_28
- update to new release by fcimport

* Wed Jan 27 2021 Igor Vlasenko <viy@altlinux.ru> 0.3.1-alt4_27
- update to new release by fcimport

* Wed Sep 02 2020 Igor Vlasenko <viy@altlinux.ru> 0.3.1-alt3_27
- update to new release by fcimport

* Thu Mar 05 2020 Igor Vlasenko <viy@altlinux.ru> 0.3.1-alt3_26
- update to new release by fcimport

* Tue Aug 06 2019 Igor Vlasenko <viy@altlinux.ru> 0.3.1-alt3_25
- update to new release by fcimport

* Fri Mar 01 2019 Igor Vlasenko <viy@altlinux.ru> 0.3.1-alt3_24
- update to new release by fcimport

* Wed Aug 01 2018 Igor Vlasenko <viy@altlinux.ru> 0.3.1-alt3_23
- update to new release by fcimport

* Tue Feb 20 2018 Igor Vlasenko <viy@altlinux.ru> 0.3.1-alt3_21
- update to new release by fcimport

* Mon Oct 09 2017 Igor Vlasenko <viy@altlinux.ru> 0.3.1-alt3_20
- update to new release by fcimport

* Wed Mar 15 2017 Igor Vlasenko <viy@altlinux.ru> 0.3.1-alt3_18
- update to new release by fcimport

* Wed Mar 02 2016 Igor Vlasenko <viy@altlinux.ru> 0.3.1-alt3_17
- update to new release by fcimport

* Mon Oct 19 2015 Igor Vlasenko <viy@altlinux.ru> 0.3.1-alt3_16
- update to new release by fcimport

* Tue Sep 16 2014 Igor Vlasenko <viy@altlinux.ru> 0.3.1-alt3_14
- update to new release by fcimport

* Mon Jul 07 2014 Igor Vlasenko <viy@altlinux.ru> 0.3.1-alt3_13
- update to new release by fcimport

* Mon Sep 09 2013 Igor Vlasenko <viy@altlinux.ru> 0.3.1-alt3_12
- update to new release by fcimport

* Mon Apr 29 2013 Igor Vlasenko <viy@altlinux.ru> 0.3.1-alt3_11
- initial fc import

* Thu Oct 30 2008 Yuri N. Sedunov <aris@altlinux.org> 0.3.1-alt3
- fixed build with g++-4.3. (thnx Gentoo)

* Tue Oct 14 2008 Yuri N. Sedunov <aris@altlinux.org> 0.3.1-alt2
- disable OSS support

* Tue Jul 11 2006 Mikhail Yakshin <greycat@altlinux.ru> 0.3.1-alt1
- 0.3.1

* Fri Jan 21 2005 Yuri N. Sedunov <aris@altlinux.ru> 0.2.7-alt4.1
- fixed build with g++-3.4. (thnx MDK).

* Thu Jun 17 2004 Yuri N. Sedunov <aris@altlinux.ru> 0.2.7-alt4
- applied tse3_sustain_patch from NoteEdit home page.

* Sun Jan 04 2004 Yuri N. Sedunov <aris@altlinux.ru> 0.2.7-alt3
- remove unusual dependendencies and buildreqs.

* Fri Dec 05 2003 Yuri N. Sedunov <aris@altlinux.ru> 0.2.7-alt2
- do not package .la files.

* Sat Mar 08 2003 Yuri N. Sedunov <aris@altlinux.ru> 0.2.7-alt1
- new version. 

* Fri Nov 29 2002 Yuri N. Sedunov <aris@altlinux.ru> 0.2.5-alt4
- rebuild 

* Fri Oct 04 2002 Yuri N. Sedunov <aris@altlinux.ru> 0.2.5-alt3
- Rebuild with new QT3/KDE3

* Sat Aug 31 2002 Yuri N. Sedunov <aris@altlinux.ru> 0.2.5-alt1
- 0.2.5

* Tue May 21 2002 Yuri N. Sedunov <aris@altlinux.ru> 0.2.3-alt1
- 0.2.3
- alsa2 >= 0.9.0rc1 required.

* Tue May 07 2002 Yuri N. Sedunov <aris@altlinux.ru> 0.1.3-alt2
- rebuilt with qt3/kde3
- buildrequires updated.

* Sat Apr 20 2002 Yuri N. Sedunov <aris@altlinux.ru> 0.1.3-alt1
- 0.1.3
- ALSA2 by default.
- aRts header detection now works (patch removed).
- buildreqires updated.

* Mon Jan 21 2002 Yuri N. Sedunov <aris@altlinux.ru> 0.1.2-alt2
- midi patch applied (fix never stoped notes bug in OSS module).

* Tue Dec 11 2001 Yuri N. Sedunov <aris@altlinux.ru> 0.1.2-alt1
- Updated to 0.1.2, Arts support restored.

* Tue Nov 06 2001 Stanislav Ievlev <inger@altlinux.ru> 0.1.1-alt4
- small spec cleanups
- subpackage devel-static removed (we haven't static libraries yet)

* Mon Nov 5 2001 Yuri N. Sedunov <aris@altlinux.ru> alt3
- separated devel-static and tse3play packages.

* Sat Nov 3 2001 Yuri N. Sedunov <aris@altlinux.ru> alt2
- disabled arts support

* Wed Oct 31 2001 Yuri N. Sedunov <aris@altlinux.ru> alt1
- First build for Sisyphus

